@@ -12,6 +12,10 @@ false = False
 null = None
 
 
+def dump(val):
+    print(json.dumps(val, indent=4, sort_keys=True))
+
+
 class ANY:  # pragma: no cover
     def __init__(self, type):
         self.type = type
@@ -40,6 +44,26 @@ def test_query_html(admin_client, snapshot):
     snapshot.assert_match(context, "context")
 
 
+def test_query_html_no_perms(admin_user, admin_client, snapshot):
+    admin_user.is_superuser = False
+    admin_user.save()
+    res = admin_client.get("/data_browser/query//.html?")
+    assert res.status_code == 200
+    context = json.loads(res.context["ctx"])
+    context["config"]["types"]["time"]["defaultValue"] = "redacted"
+    context["config"]["version"] = "redacted"
+    snapshot.assert_match(context, "context")
+
+
+def test_query_ctx(admin_client, snapshot):
+    res = admin_client.get("/data_browser/query//.ctx?")
+    assert res.status_code == 200
+    context = res.json()
+    context["config"]["types"]["time"]["defaultValue"] = "redacted"
+    context["config"]["version"] = "redacted"
+    snapshot.assert_match(context, "context")
+
+
 @pytest.mark.usefixtures("products")
 def test_query_json_bad_fields(admin_client):
     res = admin_client.get(
@@ -71,8 +95,10 @@ def test_query_csv(admin_client):
         "/data_browser/query/tests.Product/size-0,name+1,size_unit.csv?size__lt=2&id__gt=0"
     )
     assert res.status_code == 200
+    print(res.content.decode("utf-8"))
     rows = list(csv.reader(res.content.decode("utf-8").splitlines()))
-    assert rows == [["size", "name", "size_unit"], ["1", "a", "g"], ["1", "b", "g"]]
+    dump(rows)
+    assert rows == [["size", "name", "size_unit"], ["1.0", "a", "g"], ["1.0", "b", "g"]]
 
 
 @pytest.mark.usefixtures("products")
@@ -83,7 +109,7 @@ def test_query_json(admin_client):
     assert res.status_code == 200
     data = json.loads(res.content.decode("utf-8"))
 
-    print(json.dumps(data, indent=4, sort_keys=True))
+    dump(data)
     assert data == {
         "results": [[1, "a", "g"], [1, "b", "g"]],
         "fields": [
@@ -123,8 +149,10 @@ def test_view_csv(admin_client):
     view.save()
     res = admin_client.get(f"/data_browser/view/{view.pk}.csv")
     assert res.status_code == 200
+    print(res.content.decode("utf-8"))
     rows = list(csv.reader(res.content.decode("utf-8").splitlines()))
-    assert rows == [["size", "name", "size_unit"], ["1", "a", "g"], ["1", "b", "g"]]
+    dump(rows)
+    assert rows == [["size", "name", "size_unit"], ["1.0", "a", "g"], ["1.0", "b", "g"]]
 
     view.owner = User.objects.create(is_staff=True)
     view.save()
@@ -149,7 +177,7 @@ def test_view_json(admin_client):
     res = admin_client.get(f"/data_browser/view/{view.pk}.json")
     assert res.status_code == 200
     data = json.loads(res.content.decode("utf-8"))
-    print(json.dumps(data, indent=4, sort_keys=True))
+    dump(data)
     assert data == {"results": [[1, "a", "g"], [1, "b", "g"]]}
 
     view.owner = User.objects.create(is_staff=True)
